import request from '@/utils/request'

// 查询企业变更列表
export function listQyBiangeng(query) {
  return request({
    url: '/jlry/qyBiangeng/list',
    method: 'get',
    params: query
  })
}

// 查询企业变更详细
export function getQyBiangeng(id) {
  return request({
    url: '/jlry/qyBiangeng/' + id,
    method: 'get'
  })
}

// 新增企业变更
export function addQyBiangeng(data) {
  return request({
    url: '/jlry/qyBiangeng',
    method: 'post',
    data: data
  })
}

// 修改企业变更
export function updateQyBiangeng(data) {
  return request({
    url: '/jlry/qyBiangeng',
    method: 'put',
    data: data
  })
}

// 删除企业变更
export function delQyBiangeng(id) {
  return request({
    url: '/jlry/qyBiangeng/' + id,
    method: 'delete'
  })
}


//根据身份证号查询人员信息
export function getInfoByidCard(data){
	return request({
		url:"/jlry/qyBiangeng/getRenCaiInfoByUsercord",
		params:{
			usercord:data
		},
		method:"get"
	})
}


//提交传入申请
export function submitZhuanru(data){
	return request({
		url:"/jlry/qyBiangeng/submitData",
		data:data,
		method:"post"
	})
}



//查询转入申请列表
export function searchZrsq(data){
	return request({
		url:"/jlry/qyBiangeng/dwList/1",
		params:data
	})
}

//查询转出确认列表
export function searchZcqr(data){
	return request({
		url:"/jlry/qyBiangeng/dwList/2",
		params:data
	})
}


//查询转出确认列表
export function searchXiehui(data){
	return request({
		url:"/jlry/qyBiangeng/dwList/3",
		params:data
	})
}

//修改查看状态
export function changeStatus(data){
	return request({
		url:"/jlry/qyBiangeng/outDWLooked",
		data:data,
		method:"post"
	})
}

//转入公司提交
export function zhuanruSubmit(data){
	return request({
		url:"/jlry/qyBiangeng/dwOperation/1",
		data:data,
		method:"post"
	})
}

//转出公司提交
export function zhuanchuSubmit(data){
	return request({
		url:"/jlry/qyBiangeng/dwOperation/2",
		data:data,
		method:"post"
	})
}

//协会审核变更
export function xiehuiSubmit(data){
	return request({
		url:"/jlry/qyBiangeng/adminAuditBG/1",
		data:data,
		method:"post"
	})
}

//协会进行变更
export function xiehuiBiangeng(data){
	return request({
		url:"/jlry/qyBiangeng/adminAuditBG/2",
		data:data,
		method:"post"
	})
}


//转入单位删除转入申请
export function zhuanruDel(data){
	return request({
		url:"/jlry/qyBiangeng/removeDataBYId/"+data,
		method:"post"
	})
}

//协会撤回变更
export function xiehuiChehui(data){
	return request({
		url:"/jlry/qyBiangeng/adminAuditBG/3",
		data:data,
		method:"post"
	})
}


//协会批量审核
export function xiehuiPiliangShenhe(data){
	return request({
		url:"/jlry/qyBiangeng/batchOneKeyPass",
		data:data,
		method:"post"
	})
}